# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: user_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12user_service.proto\"4\n\x11\x43reateUserRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"/\n\x12\x43reateUserResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\"Z\n\x1aGetUserLoginHistoryRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x13\n\x0bpage_number\x18\x02 \x01(\r\x12\x11\n\tpage_size\x18\x03 \x01(\r\"X\n\x10UserLoginHistory\x12\x0c\n\x04\x64\x61te\x18\x01 \x01(\t\x12\x12\n\nip_address\x18\x02 \x01(\t\x12\x12\n\nuser_agent\x18\x03 \x01(\t\x12\x0e\n\x06\x64\x65vice\x18\x04 \x01(\t\"\xb7\x01\n\x1bGetUserLoginHistoryResponse\x12\"\n\x07results\x18\x01 \x03(\x0b\x32\x11.UserLoginHistory\x12\x13\n\x0btotal_count\x18\x02 \x01(\r\x12\x13\n\x0btotal_pages\x18\x03 \x01(\r\x12\x16\n\tprev_page\x18\x04 \x01(\rH\x00\x88\x01\x01\x12\x16\n\tnext_page\x18\x05 \x01(\rH\x01\x88\x01\x01\x42\x0c\n\n_prev_pageB\x0c\n\n_next_page\"(\n\x10GetUserMeRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\"@\n\x18UserOAuthProviderAccount\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\x12\n\naccount_id\x18\x02 \x01(\t\"U\n\x11GetUserMeResponse\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x31\n\x0eoauth_accounts\x18\x02 \x03(\x0b\x32\x19.UserOAuthProviderAccount2\xbb\x01\n\x04User\x12\x31\n\x06\x43reate\x12\x12.CreateUserRequest\x1a\x13.CreateUserResponse\x12L\n\x0fGetLoginHistory\x12\x1b.GetUserLoginHistoryRequest\x1a\x1c.GetUserLoginHistoryResponse\x12\x32\n\tGetUserMe\x12\x11.GetUserMeRequest\x1a\x12.GetUserMeResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'user_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CREATEUSERREQUEST._serialized_start=22
  _CREATEUSERREQUEST._serialized_end=74
  _CREATEUSERRESPONSE._serialized_start=76
  _CREATEUSERRESPONSE._serialized_end=123
  _GETUSERLOGINHISTORYREQUEST._serialized_start=125
  _GETUSERLOGINHISTORYREQUEST._serialized_end=215
  _USERLOGINHISTORY._serialized_start=217
  _USERLOGINHISTORY._serialized_end=305
  _GETUSERLOGINHISTORYRESPONSE._serialized_start=308
  _GETUSERLOGINHISTORYRESPONSE._serialized_end=491
  _GETUSERMEREQUEST._serialized_start=493
  _GETUSERMEREQUEST._serialized_end=533
  _USEROAUTHPROVIDERACCOUNT._serialized_start=535
  _USEROAUTHPROVIDERACCOUNT._serialized_end=599
  _GETUSERMERESPONSE._serialized_start=601
  _GETUSERMERESPONSE._serialized_end=686
  _USER._serialized_start=689
  _USER._serialized_end=876
# @@protoc_insertion_point(module_scope)
