class Constants:
    RESOURCE: str = "resource"
    RESOURCE_PATH: str = "path"
    RESOURCE_SERVICE: str = "service"
    RESOURCE_QUERY_PARAMS: str = "query_params"
    RESOURCE_PATH_PARAMS: str = "path_params"
    ACTION: str = "action"
    ACTION_GET: str = "GET"
    ACTION_POST: str = "POST"
    ACTION_PUT: str = "PUT"
    ACTION_DELETE: str = "DELETE"
    ACTION_PATCH: str = "PATCH"
    SUBJECT: str = "subject"
    SUBJECT_IS_USER: str = "is_user"
    SUBJECT_IS_SUPERUSER: str = "is_superuser"
    CONTEXT: str = "context"
    CONTEXT_IP_ADDRESS: str = "ip"
    CONTEXT_USER_AGENT: str = "user_agent"
